Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(183)

Unified Diff: ui/webui/resources/cr_elements/network/cr_network_list_item.js

Issue 2556253007: MD Settings: Fix internet focus and styling (Closed)
Patch Set: Restore cr:settings Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/webui/resources/cr_elements/network/cr_network_list_item.js
diff --git a/ui/webui/resources/cr_elements/network/cr_network_list_item.js b/ui/webui/resources/cr_elements/network/cr_network_list_item.js
index 8411957eca5f6194add311a1434bcf921ce91145..4ec8666753ca21d91bc436794b37dab7aa5dc1d6 100644
--- a/ui/webui/resources/cr_elements/network/cr_network_list_item.js
+++ b/ui/webui/resources/cr_elements/network/cr_network_list_item.js
@@ -47,8 +47,8 @@ Polymer({
/**
* Reflect the element's tabindex attribute to a property so that embedded
* elements (e.g. the settings button) can become keyboard focusable when
* this element has keyboard focus.
*/
tabindex: {
type: Number,
@@ -146,7 +146,7 @@ Polymer({
},
/** @private */
- isSettingsButtonVisible_: function() {
+ isSubpageButtonVisible_: function() {
return !!this.networkState && this.showButtons;
},
« no previous file with comments | « ui/webui/resources/cr_elements/network/cr_network_list_item.html ('k') | ui/webui/resources/cr_elements/shared_style_css.html » ('j') | no next file with comments »
@@ -47,8 +47,8 @@ Polymer({
/**
* Reflect the element's tabindex attribute to a property so that embedded
- * elements (e.g. the settings button) can become keyboard focusable when
- * this element has keyboard focus.
+ * elements (e.g. the show subpage button) can become keyboard focusable
+ * when this element has keyboard focus.
*/
tabindex: {

Powered by Google App Engine
This is Rietveld 408576698